==> rdg-corp-rdg-blocks-1.0.45-baa1ae.zip: README.md <==
# RDG Corp / RDG Blocks Plugin for WordPress

Tags: rdg corp, rdg blocks, rdg, corp
Requires at least: 6.0
Tested up to: 6.0
Requires PHP: 8.1
Stable tag: 1.0.45
License: GPLv3 or later
License URI: http://www.gnu.org/licenses/gpl-3.0.html

# Changelog
- 1.0.45 (2023-01-24)
    * RDG-049-create-top-cappers-block:
        - The Top Cappers block is created.
- 1.0.44 (2023-01-24)
    * RDG-048-create-main-promotions-block:
        - The Main Promotions block is created.
- 1.0.43 (2023-01-23)
    * RDG-045-create-picks-vs-block:
        - The Picks Vs block is created.
- 1.0.42 (2023-01-21)
    * RDG-045-update-buttons-block:
        - Updated rdg buttons block.
- 1.0.41 (2023-01-20)
    * RDG-044-create-new-paragraph-custom-block:
        - The New Paragraph Custom block is created.
- 1.0.40 (2023-01-20)
    * RDG-043-adapt-blocks-full-screen:
        - It is allowed to show the selected blocks as full screen.
- 1.0.39 (2023-01-20)
    * RDG-042-create-posts-list-block:
        - The Posts List is created.
- 1.0.38 (2023-01-19)
    * RDG-041-update-faq-block:
        - Updated faq block.
- 1.0.37 (2023-01-18)
    * RDG-040-create-paragraph-custom-block:
        - The Paragraph Custom block is created.
- 1.0.36 (2023-01-18)
    * RDG-039-create-sports-picks-vs-block:
        - The Sports Picks Vs block is created.
- 1.0.35 (2023-01-12)
    * RDG-038-create-odd-betting-block:
        - The odd betting select block is created.
        - The odd betting date block is created.
        - The title block is approved.
        - The main banner block is modified.
- 1.0.34 (2023-01-11)
    * RDG-037-update-main-banner-block:
        - The main banner block is updated.
- 1.0.33 (2023-01-10)
    * RDG-036-create-logo-team-block:
        - The rdg logo team block was created.
- 1.0.32 (2023-01-10)
    * RDG-035-buttons-block:
        - The rdg buttons block was created.
- 1.0.31 (2023-01-10)
    * RDG-034-faq-block:
        - Frequently asked questions on how to adapt the block.
- 1.0.30 (2023-01-09)
    * RDG-033-fix-next-game-block:
        - The media query of the block next game is fixed.
- 1.0.29 (2023-01-09)
    * RDG-032-update-next-game-block:
        - The media queries of the block are modified.
- 1.0.28 (2023-01-06)
    * RDG-030-adapt-image-column:
        - The Image Column block was created.
- 1.0.27 (2023-01-05)
    * RDG-029-fit-multiple-blocks:
        - Multiple blocks were adjusted.
- 1.0.26 (2023-01-04)
    * RDG-028-create-picks-list-block:
        - The picks list block was created.
- 1.0.25 (2023-01-04)
    * RDG-027-create-latest-post-block:
        - The latest post block was created.
- 1.0.24 (2023-01-03)
    * RDG-026-create-slider-latest-post:
        - The slider latest post block was created.
- 1.0.23 (2022-12-23)
    * RDG-025-create-next-game-block:
        - The next game block was created.
- 1.0.22 (2022-12-22)
    * RDG-024-create-admin-cappers-block:
        - The admin cappers block was created.
- 1.0.21 (2022-12-20)
    * RDG-023-call-to-action-block:
        - The design of the call to action block is adapted.
- 1.0.20 (2022-12-19)
    * RDG-022-main-banner-block:
        - The design of the main banner block was adapted for the generatePress theme.
- 1.0.19 (2022-12-17)
    * RDG-021-sports-picks-api-fix:
        - Sports picks block is repaired.
- 1.0.18 (2022-12-17)
    * RDG-020-sports-picks-api:
        - API was implemented in the sports picks block. 
- 1.0.17 (2022-12-09)
    * RDG-019-create-block-sports-picks:
        - The design of the sports picks block was adapted to the generatePress template. 
        - Fixed cache problem, when a block that supports it, uses manual data.
- 1.0.16 (2022-12-08)
    * RDG-018-top-winners-done:
        - The top winners block is finished.
- 1.0.15 (2022-12-07)
    * RDG-017-top-winners-multi_caching:
        - A cache file is generated for each block.
- 1.0.14 (2022-12-06)
    * RDG-016-top-winners-cache-fix:
        - Blocks are identified for cache and processed on save.
- 1.0.13 (2022-12-02)
    * RDG-015-top-winners-cache-uploads:
        - Cache storage path changed.
- 1.0.12 (2022-12-02)
    * RDG-014-top-winners-cache-fix:
        - The directory for the cache is created if it does not exist.
- 1.0.11 (2022-12-02)
    * RDG-013-top-winners-cache:
        - Implement cache api.
- 1.0.10 (2022-12-01)
    * RDG-012-top-winner-api:
        - Adapted the Top Winner block to connect with API.
- 1.0.9 (2022-11-30)
    * RDG-011-adapt-top-winner-block:
        - Adapt top winner block to generatePress theme.
- 1.0.8 (2022-11-22)
    * RDG-010-create-sports-picks-block:
        - The RDG Sports Picks block was created.
        - Sources ACF .json updated.
- 1.0.7 (2022-11-21)
    * RDG-009-create-top-winners-block:
        - The RDG Top Winners block was created.
        - Sources ACF .json updated.
- 1.0.6 (2022-11-18)
    * RDG-008-update-image-column-block:
        - Removed manual adjustments from the block image column.
- 1.0.5 (2022-11-18)
    * RDG-006-fix-image-column-block:
        - It is validated that the link should not be blank.
- 1.0.4 (2022-11-17)
    * RDG-005-create-image-column-block:
        - The RDG Image Column block was created.
        - Sources ACF .json updated.
- 1.0.3 (2022-11-16)
    * RDG-004-create-call-to-action-block:
        - The RDG Call to Action block was created.
        - Sources ACF .json updated.
- 1.0.2 (2022-11-16)
    * RDG-003-modify-main-banner-block:
        - Removed main banner block title. 
        - The RDG Title block was created.
        - Sources ACF .json updated.
- 1.0.1 (2022-11-15)
    * RDG-002-create-main-banner-block:
        - Main banner block was created. 
        - Common structures are created for the different blocks.
        - Sources ACF .json created.
- 1.0.0 (2022-11-11)
    - RDG-001: Block base structure is implemented.

==> rdg-corp-rdg-blocks-1.0.48-64835e.zip: README.md <==
# RDG Corp / RDG Blocks Plugin for WordPress

Tags: rdg corp, rdg blocks, rdg, corp
Requires at least: 6.0
Tested up to: 6.0
Requires PHP: 8.1
Stable tag: 1.0.48
License: GPLv3 or later
License URI: http://www.gnu.org/licenses/gpl-3.0.html

# Changelog
- 1.0.48 (2023-01-26)
    * RDG-052-create-logo-ranking-block:
        - The Logo Ranking block is created.
- 1.0.47 (2023-01-25)
    * RDG-051-create-leader-board-block:
        - The Leader Board block is created.
- 1.0.46 (2023-01-25)
    * RDG-050-create-favorite-cappers-block:
        - The Favorite Cappers block is created.
- 1.0.45 (2023-01-24)
    * RDG-049-create-top-cappers-block:
        - The Top Cappers block is created.
- 1.0.44 (2023-01-24)
    * RDG-048-create-main-promotions-block:
        - The Main Promotions block is created.
- 1.0.43 (2023-01-23)
    * RDG-045-create-picks-vs-block:
        - The Picks Vs block is created.
- 1.0.42 (2023-01-21)
    * RDG-045-update-buttons-block:
        - Updated rdg buttons block.
- 1.0.41 (2023-01-20)
    * RDG-044-create-new-paragraph-custom-block:
        - The New Paragraph Custom block is created.
- 1.0.40 (2023-01-20)
    * RDG-043-adapt-blocks-full-screen:
        - It is allowed to show the selected blocks as full screen.
- 1.0.39 (2023-01-20)
    * RDG-042-create-posts-list-block:
        - The Posts List is created.
- 1.0.38 (2023-01-19)
    * RDG-041-update-faq-block:
        - Updated faq block.
- 1.0.37 (2023-01-18)
    * RDG-040-create-paragraph-custom-block:
        - The Paragraph Custom block is created.
- 1.0.36 (2023-01-18)
    * RDG-039-create-sports-picks-vs-block:
        - The Sports Picks Vs block is created.
- 1.0.35 (2023-01-12)
    * RDG-038-create-odd-betting-block:
        - The odd betting select block is created.
        - The odd betting date block is created.
        - The title block is approved.
        - The main banner block is modified.
- 1.0.34 (2023-01-11)
    * RDG-037-update-main-banner-block:
        - The main banner block is updated.
- 1.0.33 (2023-01-10)
    * RDG-036-create-logo-team-block:
        - The rdg logo team block was created.
- 1.0.32 (2023-01-10)
    * RDG-035-buttons-block:
        - The rdg buttons block was created.
- 1.0.31 (2023-01-10)
    * RDG-034-faq-block:
        - Frequently asked questions on how to adapt the block.
- 1.0.30 (2023-01-09)
    * RDG-033-fix-next-game-block:
        - The media query of the block next game is fixed.
- 1.0.29 (2023-01-09)
    * RDG-032-update-next-game-block:
        - The media queries of the block are modified.
- 1.0.28 (2023-01-06)
    * RDG-030-adapt-image-column:
        - The Image Column block was created.
- 1.0.27 (2023-01-05)
    * RDG-029-fit-multiple-blocks:
        - Multiple blocks were adjusted.
- 1.0.26 (2023-01-04)
    * RDG-028-create-picks-list-block:
        - The picks list block was created.
- 1.0.25 (2023-01-04)
    * RDG-027-create-latest-post-block:
        - The latest post block was created.
- 1.0.24 (2023-01-03)
    * RDG-026-create-slider-latest-post:
        - The slider latest post block was created.
- 1.0.23 (2022-12-23)
    * RDG-025-create-next-game-block:
        - The next game block was created.
- 1.0.22 (2022-12-22)
    * RDG-024-create-admin-cappers-block:
        - The admin cappers block was created.
- 1.0.21 (2022-12-20)
    * RDG-023-call-to-action-block:
        - The design of the call to action block is adapted.
- 1.0.20 (2022-12-19)
    * RDG-022-main-banner-block:
        - The design of the main banner block was adapted for the generatePress theme.
- 1.0.19 (2022-12-17)
    * RDG-021-sports-picks-api-fix:
        - Sports picks block is repaired.
- 1.0.18 (2022-12-17)
    * RDG-020-sports-picks-api:
        - API was implemented in the sports picks block. 
- 1.0.17 (2022-12-09)
    * RDG-019-create-block-sports-picks:
        - The design of the sports picks block was adapted to the generatePress template. 
        - Fixed cache problem, when a block that supports it, uses manual data.
- 1.0.16 (2022-12-08)
    * RDG-018-top-winners-done:
        - The top winners block is finished.
- 1.0.15 (2022-12-07)
    * RDG-017-top-winners-multi_caching:
        - A cache file is generated for each block.
- 1.0.14 (2022-12-06)
    * RDG-016-top-winners-cache-fix:
        - Blocks are identified for cache and processed on save.
- 1.0.13 (2022-12-02)
    * RDG-015-top-winners-cache-uploads:
        - Cache storage path changed.
- 1.0.12 (2022-12-02)
    * RDG-014-top-winners-cache-fix:
        - The directory for the cache is created if it does not exist.
- 1.0.11 (2022-12-02)
    * RDG-013-top-winners-cache:
        - Implement cache api.
- 1.0.10 (2022-12-01)
    * RDG-012-top-winner-api:
        - Adapted the Top Winner block to connect with API.
- 1.0.9 (2022-11-30)
    * RDG-011-adapt-top-winner-block:
        - Adapt top winner block to generatePress theme.
- 1.0.8 (2022-11-22)
    * RDG-010-create-sports-picks-block:
        - The RDG Sports Picks block was created.
        - Sources ACF .json updated.
- 1.0.7 (2022-11-21)
    * RDG-009-create-top-winners-block:
        - The RDG Top Winners block was created.
        - Sources ACF .json updated.
- 1.0.6 (2022-11-18)
    * RDG-008-update-image-column-block:
        - Removed manual adjustments from the block image column.
- 1.0.5 (2022-11-18)
    * RDG-006-fix-image-column-block:
        - It is validated that the link should not be blank.
- 1.0.4 (2022-11-17)
    * RDG-005-create-image-column-block:
        - The RDG Image Column block was created.
        - Sources ACF .json updated.
- 1.0.3 (2022-11-16)
    * RDG-004-create-call-to-action-block:
        - The RDG Call to Action block was created.
        - Sources ACF .json updated.
- 1.0.2 (2022-11-16)
    * RDG-003-modify-main-banner-block:
        - Removed main banner block title. 
        - The RDG Title block was created.
        - Sources ACF .json updated.
- 1.0.1 (2022-11-15)
    * RDG-002-create-main-banner-block:
        - Main banner block was created. 
        - Common structures are created for the different blocks.
        - Sources ACF .json created.
- 1.0.0 (2022-11-11)
    - RDG-001: Block base structure is implemented.
